==> xld-ci-explorer-6.2.0.jar: web/languages/en-US/ciExplorer.lang.js <==
/* eslint-disable  max-len*/
export default {
    abortButton: 'Abort',
    aboutBoxClasspathTabTitle: 'Server Classpath',
    aboutBoxInstalledPluginsTabTitle: 'Installed Plugins',
    aboutBoxLicenseTabTitle: 'License',
    aboutBoxVersionTabTitle: 'Version',
    aboutOption: 'About',
    actionsTitle: 'Actions',
    addNewRoleLabel: 'New role',
    adminPermissionTitle: 'admin',
    blockLogMessage: 'There is no log output for task blocks. Please select a step to view the log output.',
    cancelButton: 'Cancel',
    cancelCurrentTaskMessage: 'Are you sure you want to cancel the current task?',
    cancelTaskButton: 'Cancel task',
    cantArchiveMessage: 'The task cannot be archived through the CI Explorer. Please use the Deployment Workspace to archive the task',
    cantArchiveTitle: "Can't archive",
    cantRenameBodyMessage: 'Cannot rename CI because the new name is empty or contains characters that are not allowed.',
    cantRenameTitle: "Can't rename",
    cantUndeployMessage: 'The package cannot be undeployed through the CI Explorer. Please use the Deployment Workspace to undeploy the package.',
    cantUndeployTitle: "Can't undeploy",
    chooseFileLabel: 'Choose file',
    ciIdDescription: 'Full item folder structure.',
    ciNameDescription: 'The name for the application version.',
    ciTypeDescription: 'The type of a configuration item.',
    clearButton: 'Clear',
    clearButtonTitle: 'Clear all the permissions for this role.',
    closeButton: 'Close',
    closePreviewButton: 'Close preview',
    configureTitle: 'Configure',
    confirmDeleteCI: 'Are you sure you want to delete ',
    confirmDeleteRole: 'You are about to delete role <%= name %>. Are you sure?',
    confirmRollback: 'Are you sure you want to rollback the current task?',
    continueButton: 'Continue',
    controlTaskExecutePermissionTitle: 'control task execute',
    copyrightNotice: 'Copyright © XebiaLabs Group. All rights reserved.',
    currentlyDeployedVersion: '<%= envName %> (currently deployed: <%= currentlyDeployed %>)',
    daysSuffix: 'day',
    deleteAction: 'Delete',
    deleteRoleLabel: 'Delete role <%= name %> ?',
    deployAction: 'Deploy',
    deployButton: 'Deploy',
    deployedAppNameTitle: '<%= id%> (<%= version %>)',
    deployedPanelValidationMessage: '<%= messageCount %> <%= level %><% if(messageCount > 1) {%>s<%} %>',
    deployedValidationNameNotUnique: 'The deployed must have a unique name within the container',
    deployedValidationNotificationMessage: '<%= message %> for <%= property %>',
    deployFlowTitle: '<%= application %>/<%= version %> to <%= environment %>',
    deployInitialPermissionTitle: 'deploy initial',
    deploymentPanelHeader: '<%= deploymentType %> DEPLOYMENT',
    deploymentPropertiesButton: 'Deployment Properties',
    deploymentPropertiesTitle: 'Deployment Properties',
    deploymentsReportCompletionDateColumnName: 'End Date',
    deploymentsReportDeploymentTypeColumnName: 'Deployment Type',
    deploymentsReportEnvironmentColumnName: 'Environment',
    deploymentsReportPackageColumnName: 'Package(s)',
    deploymentsReportStartDateColumnName: 'Start Date',
    deploymentsReportStatusColumnName: 'Status',
    deploymentsReportTabTitle: 'Deployments',
    deploymentsReportUserColumnName: 'User',
    deploymentStatusCancelled: 'Cancelled',
    deploymentStatusDone: 'Done',
    deploymentTypeInitial: 'Initial',
    deploymentTypeRollback: 'Rollback',
    deploymentTypeUndeployment: 'Undeployment',
    deploymentTypeUpdate: 'Update',
    deployUndeployPermissionTitle: 'deploy undeploy',
    deployUpgradePermissionTitle: 'deploy upgrade',
    descriptionLabel: 'Description',
    discoveryPermissionTitle: 'discovery',
    doNotDeleteButton: 'Do not delete',
    duplicateAction: 'Duplicate',
    editAction: 'Edit',
    editionLabel: 'Edition',
    editPermissionsAction: 'Edit permissions',
    editRoleLabel: 'Edit <%= name %> role',
    emptyTargetedLabel: 'targeted (No deployables could be mapped)',
    endDateLabel: 'End date',
    environmentsUnavailableMessage: 'You cannot deploy because there are no environments available',
    errorTitleOfRenamingCi: 'Error renaming CI',
    executeButton: 'Execute',
    execution: 'Execution',
    executionPlanTitle: 'EXECUTION PLAN',
    executionTitle: 'Execution',
    explorerTab: 'Explorer',
    exportReport: 'Export report',
    filterButton: 'Filter',
    finishButton: 'Finish',
    finishLabel: 'Finish',
    genericToastrErrorTitle: 'Error',
    globalPermissionsTabTitle: 'Global Permissions',
    headerInitialDeployment: 'INITIAL DEPLOYMENT',
    headerInitialOrUpdateDeployment: 'DEPLOYMENT',
    headerRollbackDeployment: 'ROLLBACK',
    headerUndeployment: 'UNDEPLOYMENT',
    headerUpdateDeployment: 'UPDATE DEPLOYMENT',
    hideButton: 'Hide',
    hideFiltersButton: 'Hide filters',
    hostsLabel: 'Hosts',
    hoursSuffix: 'hr',
    idLabel: 'ID',
    importInitialPermissionTitle: 'import initial',
    importRemovePermissionTitle: 'import remove',
    importUpgradePermissionTitle: 'import upgrade',
    incompleteInitialDeploymentTitle: '<%= basename %> to ...',
    incorrectCredentialsMessage: 'The username or password you have entered is incorrect.',
    invalidCharactersLabel: 'Please enter only valid characters for the Name (no `/`, :`, `[`, `]`, `|`, `,` or `*`)',
    keepMeLoggedInLabel: 'Keep me logged in',
    lastUpdatedTimestamp: 'Last updated: <%= timestamp %>',
    legacyInterfaceOption: 'Go to legacy interface',
    libraryLabel: 'Library',
    licensedApplicationsLabel: 'Licensed # of Applications',
    licensedContactLabel: 'License contact',
    licenseDescription: 'The limits of your XL Deploy license apply to all instances of XL Deploy that use the license. For compliance purposes, please ensure that the total number of configuration items used in all instances does not exceed the limits of the license.',
    licensedHostsLabel: 'Licensed # of Hosts',
    licensedPluginsLabel: 'Licensed plugins',
    licensedSatellitesLabel: 'Licensed # of Satellites',
    licensedToLabel: 'Licensed to',
    licenseExpiredMessage: 'This XL Deploy server will not function due to a license problem. Please contact your administrator or enter a valid license <a href="productregistration" target="_blank">here</a>.',
    licenseExpiryDateLabel: 'License expires after',
    licenseUsage: '<%= licensed %> (in use: <%= inUse %>)',
    loggedInAsLabel: 'Logged in as',
    loginButton: 'Login',
    loginPermissionTitle: 'login',
    loginTitle: 'Login',
    logoutOption: 'Log out',
    lostChangesNotification: 'Are you sure you want to leave? Your changes will be lost.',
    millisecondsSuffix: 'ms',
    minutesSuffix: 'min',
    modifyPlanButton: 'Modify plan',
    nameLabel: 'Name',
    newAction: 'New',
    newRoleAction: 'Add role',
    noButton: 'No',
    noLoginPermissions: 'You do not have permission to log in. Please contact your system administrator.',
    noSearchResultsText: 'No results found',
    nothingToMapLabel: 'There are no containers in the environment',
    onlineDocumentation: 'Online documentation',
    openCIPermissionsTitle: '<%= basename %> permissions',
    orderLabel: 'Order',
    passwordLabel: 'Password',
    passwordPlaceholder: 'Password',
    pauseAfterButton: 'Pause after',
    pauseBeforeButton: 'Pause before',
    pendingLogMessage: 'There is no log output available for pending steps.',
    pluginColumnTitle: 'Plugin',
    previewButton: 'Preview',
    previewPermissionNotGivenLabel: 'You do not have permission to preview the step.',
    previewTitle: 'Preview',
    previewUnavailableLabel: 'Preview not available',
    principalsDescription: 'Type in names for principals.',
    principalsTitle: 'Principals',
    productNameLabel: 'Product',
    readPermissionTitle: 'read',
    refreshButton: 'Refresh',
    remainingDays: 'days remaining: <%= remainingDays %>',
    renameAction: 'Rename',
    renamingCiErrorTitle: 'Error renaming CI',
    repoEditPermissionTitle: 'repo edit',
    reportEmptyMessage: 'No report data available for the selected filter',
    reportErrorMessage: 'Error while fetching report',
    reportPaginationTotals: 'Total: <%= total %>',
    reportsTab: 'Reports',
    reportTabDeployments: 'Deployments',
    reportViewPermissionTitle: 'report view',
    resetButton: 'Reset',
    roleDescription: 'Provide a unique name for the role.',
    roleExitsLabel: 'Role name <%= name %> already exists',
    rolesColumnTitle: 'Roles',
    rolesTabTitle: 'Roles',
    roleTitle: 'Role',
    rollbackButton: 'Rollback',
    rollbackFlowTitle: 'Roll back <%= application %>/<%= version %> from <%= environment %>',
    ruleLabel: 'Rule',
    satellitesLabel: 'Satellites',
    saveButton: 'Save',
    searchCiInputPlaceholder: 'Search',
    secondsSuffix: 'sec',
    securityEditPermissionTitle: 'security edit',
    selectEnvironmentTitle: 'Select Environment',
    selectVersionTitle: 'Select Package',
    serverVersion: 'Server version: <%= serverVersion %>',
    sessionExpiredMessage: 'Session has been expired',
    showButton: 'Show',
    showFiltersButton: 'Show filters',
    skipButton: 'Skip',
    sourcePathLabel: 'Source path',
    stageConfigure: 'Configure',
    stageDeploy: 'Deploy',
    stageExecution: 'Execution',
    stageRollback: 'Rollback',
    stageUndeploy: 'Undeploy',
    startDateLabel: 'Start date',
    startLabel: 'Start',
    stepLogMessage: 'There is no log output available for a <%= state %> step.',
    stepNumberLabel: 'Step number',
    stepScriptTitle: 'Step preview',
    stopButton: 'Stop',
    submitSupportRequest: 'Submit a support request',
    suggestFeature: 'Suggest a feature',
    supportPolicyLabel: 'Support policy',
    targetedLabel: 'targeted',
    taskAssignPermissionTitle: 'task assign',
    taskIdTitle: 'Task ID',
    taskMoveStepPermissionTitle: 'task move step',
    taskPreviewStepPermissionTitle: 'task preview step',
    taskSkipStepPermissionTitle: 'task skip step',
    taskTakeoverPermissionTitle: 'task takeover',
    taskWillBeAbortedNotification: 'Closing this tab will abort the running task. Are you sure you want to abort?',
    totalLabel: 'Total',
    typeLabel: 'Type',
    undeployAction: 'Undeploy',
    undeployButton: 'Undeploy',
    undeployFlowTitle: 'Undeploy <%= application %> from <%= environment %>',
    uniqueNameLabel: 'Please provide a unique name.',
    unknownErrorMessage: 'The application has encountered an unknown error.',
    unknownErrorTitle: 'Error',
    unsavedChangedMessage: 'There are unsaved changes. Are you sure you want to discard these changes?',
    unskipButton: 'Unskip',
    untargetedLabel: 'untargeted',
    updateAction: 'Update',
    updateFlowTitle: 'Update deployment',
    userLabel: 'User',
    usermanagementTab: 'User Management',
    userPlaceholder: 'User',
    validationErrorTitle: 'Validation Error',
    versionColumnTitle: 'Version',
    warningsLabel: 'Warnings',
    weeksSuffix: 'wk',
    welcomePanelText: 'Double-click a configuration item on the left to open it.',
    xebialabsWebsite: 'XebiaLabs website',
    yesButton: 'Yes',
    zeroTimeLabel: '0 sec'
};

==> xld-ci-explorer-7.0.0.jar: web/languages/en-US/ciExplorer.lang.js <==
/* eslint-disable  max-len*/
export default {
    abortButton: 'Abort',
    aboutBoxClasspathTabTitle: 'Server Classpath',
    aboutBoxInstalledPluginsTabTitle: 'Installed Plugins',
    aboutBoxLicenseTabTitle: 'License',
    aboutBoxVersionTabTitle: 'Version',
    aboutOption: 'About',
    actionsTitle: 'Actions',
    addNewRoleLabel: 'New role',
    adminPermissionTitle: 'admin',
    allTasksButton: 'All tasks',
    blockLogMessage: 'There is no log output for task blocks. Please select a step to view the log output.',
    cancelButton: 'Cancel',
    cancelCurrentTaskMessage: 'Are you sure you want to cancel the current task?',
    cancelTaskButton: 'Cancel task',
    cantArchiveMessage: 'The task cannot be archived through the CI Explorer. Please use the Deployment Workspace to archive the task',
    cantArchiveTitle: "Can't archive",
    cantRenameBodyMessage: 'Cannot rename CI because the new name is empty or contains characters that are not allowed.',
    cantRenameTitle: "Can't rename",
    cantUndeployMessage: 'The package cannot be undeployed through the CI Explorer. Please use the Deployment Workspace to undeploy the package.',
    cantUndeployTitle: "Can't undeploy",
    chooseFileLabel: 'Choose file',
    ciHistoryTitle: 'History of <%= ciId %>',
    ciIdDescription: 'Full item folder structure.',
    ciNameDescription: 'The name for the application version.',
    ciTypeDescription: 'The type of a configuration item.',
    clearButton: 'Clear',
    clearButtonTitle: 'Clear all the permissions for this role.',
    closeAllTabsAction: 'Close all tabs',
    closeButton: 'Close',
    closeOtherTabsAction: 'Close other tabs',
    closePreviewButton: 'Close preview',
    compareMenuProperty: 'Compare',
    compareWithPreviousAction: 'With previous version',
    configureTitle: 'Configure',
    confirmDeleteCI: 'Are you sure you want to delete ',
    confirmDeleteRole: 'You are about to delete role <%= name %>. Are you sure?',
    confirmLeaveCiSaveTitle: 'Leave without saving <%= ciName %>?',
    confirmMoveCi: 'Are you sure you want to move <%= sourceCiName %> to <%= targetCiId %>?',
    confirmMoveTitle: 'Confirm move',
    confirmRollback: 'Are you sure you want to rollback the current task?',
    continueButton: 'Continue',
    controlFlowTitle: '<%= taskLabel %> <%= getCiName(controlTaskTargetCI) %>',
    controlTaskExecutePermissionTitle: 'control task execute',
    controlTasksTitle: 'Control tasks',
    copyrightNotice: 'Copyright © XebiaLabs Group. All rights reserved.',
    currentlyDeployedVersion: '<%= envName %> (currently deployed: <%= currentlyDeployed %>)',
    dateFormat: 'DD/MM/YYYY',
    daysSuffix: 'day',
    deleteAction: 'Delete',
    deleteRoleLabel: 'Delete role <%= name %> ?',
    deployAction: 'Deploy',
    deployButton: 'Deploy',
    deployedAppNameTitle: '<%= id%> (<%= version %>)',
    deployedPanelValidationMessage: '<%= messageCount %> <%= level %><% if(messageCount > 1) {%>s<%} %>',
    deployedValidationNameNotUnique: 'The deployed must have a unique name within the container',
    deployedValidationNotificationMessage: '<%= message %> for <%= property %>',
    deployFlowTitle: '<%= application %>/<%= version %> to <%= environment %>',
    deployInitialPermissionTitle: 'deploy initial',
    deployment: 'deployment',
    deploymentPanelHeader: '<%= deploymentType %> DEPLOYMENT',
    deploymentPropertiesButton: 'Deployment Properties',
    deploymentPropertiesTitle: 'Deployment Properties',
    deploymentsReportCompletionDateColumnName: 'End Date',
    deploymentsReportDeploymentTypeColumnName: 'Deployment Type',
    deploymentsReportEnvironmentColumnName: 'Environment',
    deploymentsReportPackageColumnName: 'Package(s)',
    deploymentsReportStartDateColumnName: 'Start Date',
    deploymentsReportStatusColumnName: 'Status',
    deploymentsReportTabTitle: 'Deployments',
    deploymentsReportUserColumnName: 'User',
    deploymentStatusCancelled: 'Cancelled',
    deploymentStatusDone: 'Done',
    deploymentTasksTitle: 'Deployment tasks',
    deploymentTypeInitial: 'Initial',
    deploymentTypeRollback: 'Rollback',
    deploymentTypeUndeploy: 'Undeploy',
    deploymentTypeUndeployment: 'Undeployment',
    deploymentTypeUpdate: 'Update',
    deploymentTypeUpgrade: 'Upgrade',
    deployUndeployPermissionTitle: 'deploy undeploy',
    deployUpgradePermissionTitle: 'deploy upgrade',
    descriptionLabel: 'Description',
    discoveryPermissionTitle: 'discovery',
    doNotDeleteButton: 'Do not delete',
    duplicateAction: 'Duplicate',
    editAction: 'Edit',
    editDeployedItem: 'Edit deployed item',
    editionLabel: 'Edition',
    editPermissionsAction: 'Edit permissions',
    editRoleLabel: 'Edit <%= name %> role',
    emptyTargetedLabel: 'targeted (No deployables could be mapped)',
    endDateLabel: 'End date',
    environmentLabel: 'Environment',
    environmentsUnavailableMessage: 'You cannot deploy because there are no environments available',
    errorTitleOfRenamingCi: 'Error renaming CI',
    executeButton: 'Execute',
    executionPlanTitle: 'EXECUTION PLAN',
    executionTitle: 'Execution',
    explorerTab: 'Explorer',
    exportAction: 'Export',
    exportReport: 'Export report',
    filterButton: 'Filter',
    finishButton: 'Finish',
    finishLabel: 'Finish',
    generatingPreviewText: 'Generating preview...',
    genericToastrErrorTitle: 'Error',
    globalPermissionsTabTitle: 'Global Permissions',
    headerInitialDeployment: 'INITIAL DEPLOYMENT',
    headerInitialOrUpdateDeployment: 'DEPLOYMENT',
    headerRollbackDeployment: 'ROLLBACK',
    headerUndeployment: 'UNDEPLOYMENT',
    headerUpdateDeployment: 'UPDATE DEPLOYMENT',
    hideButton: 'Hide',
    hideFiltersButton: 'Hide filters',
    hostsLabel: 'Hosts',
    hoursSuffix: 'hr',
    idLabel: 'ID',
    importButton: 'Import',
    importFromComputerAction: 'From computer',
    importFromUrlAction: 'From URL',
    importFromXlDeployServerAction: 'From XL Deploy server',
    importInitialPermissionTitle: 'import initial',
    importMenuProperty: 'Import',
    importPackageFromComputerDescription: 'Package to import.',
    importPackageFromComputerLabel: 'Package',
    importPackageFromComputerTitle: 'Import from computer',
    importPackageFromUrlLabel: 'URL',
    importPackageFromUrlTitle: 'Import from URL',
    importPackageFromXlDeployServerDescription: 'Package to import.',
    importPackageFromXlDeployServerLabel: 'Package',
    importPackageFromXlDeployServerTitle: 'Import from XL Deploy server',
    importPackagePasswordDescription: 'Password to use when importing the package.',
    importPackagePasswordLabel: 'Password',
    importPackageUrlDescription: 'Location of the package (for example, a CI server or artifact repository).',
    importPackageUserDescription: 'User name to use when importing the package.',
    importPackageUserLabel: 'User',
    importRemovePermissionTitle: 'import remove',
    importUpgradePermissionTitle: 'import upgrade',
    incompleteInitialDeploymentTitle: '<%= basename %> to ...',
    incompleteUpdateDeploymentTitle: '... to <%= environmentName%>',
    incorrectCredentialsMessage: 'The username or password you have entered is incorrect.',
    infoTitle: 'Information',
    inProgress: 'In progress',
    invalidCharactersLabel: 'Please enter only valid characters for the Name (no `/`, :`, `[`, `]`, `|`, `,` or `*`)',
    invalidUrlLabel: 'Please enter a valid url',
    keepMeLoggedInLabel: 'Keep me logged in',
    lastUpdatedTimestamp: 'Last updated: <%= timestamp %>',
    leaveAction: 'Leave',
    legacyInterfaceOption: 'Go to legacy interface',
    libraryLabel: 'Library',
    licensedApplicationsLabel: 'Licensed # of Applications',
    licensedContactLabel: 'License contact',
    licenseDescription: 'The limits of your XL Deploy license apply to all instances of XL Deploy that use the license. For compliance purposes, please ensure that the total number of configuration items used in all instances does not exceed the limits of the license.',
    licensedHostsLabel: 'Licensed # of Hosts',
    licensedPluginsLabel: 'Licensed plugins',
    licensedSatellitesLabel: 'Licensed # of Satellites',
    licensedToLabel: 'Licensed to',
    licenseExpiredMessage: 'This XL Deploy server will not function due to a license problem. Please contact your administrator or enter a valid license <a href="productregistration" target="_blank">here</a>.',
    licenseExpiryDateLabel: 'License expires after',
    licenseUsage: '<%= licensed %> (in use: <%= inUse %>)',
    loggedInAsLabel: 'Logged in as',
    loginButton: 'Login',
    loginPermissionTitle: 'login',
    loginTitle: 'Login',
    logoutOption: 'Log out',
    lostChangesNotification: 'Are you sure you want to leave? Your changes will be lost.',
    mapAllDeployables: 'Map all deployables',
    mapDeployable: 'Map deployable',
    millisecondsSuffix: 'ms',
    minutesSuffix: 'min',
    modifyPlanButton: 'Modify plan',
    moveAction: 'Move',
    myTasksButton: 'My tasks',
    nameLabel: 'Name',
    newAction: 'New',
    newRoleAction: 'Add role',
    noButton: 'No',
    noDataLabel: 'No Data',
    noLeadingOrTrailingSpaces: (ciName) => `The CI name [${ciName}] must not contain leading or trailing spaces`,
    noLoginPermissions: 'You do not have permission to log in. Please contact your system administrator.',
    noPreviousRevisionsMessage: 'There are no previous versions',
    noSearchResultsText: 'No results found',
    nothingToMapLabel: 'There are no containers in the environment',
    onlineDocumentation: 'Online documentation',
    openCIPermissionsTitle: '<%= basename %> permissions',
    orderLabel: 'Order',
    packageLabel: 'Package',
    passwordLabel: 'Password',
    passwordPlaceholder: 'Password',
    pastTimeErrorText: 'Scheduled date and time must be in the future',
    pauseAfterButton: 'Pause after',
    pauseBeforeButton: 'Pause before',
    pendingLogMessage: 'There is no log output available for pending steps.',
    pluginColumnTitle: 'Plugin',
    previewButton: 'Preview',
    previewPermissionNotGivenLabel: 'You do not have permission to preview the step.',
    previewTitle: 'Preview',
    previewUnavailableLabel: 'Preview not available',
    principalsDescription: 'Type in names for principals.',
    principalsTitle: 'Principals',
    productNameLabel: 'Product',
    readPermissionTitle: 'read',
    refreshButton: 'Refresh',
    remainingDays: 'days remaining: <%= remainingDays %>',
    removeDeployable: 'Remove deployable',
    removeDeployed: 'Remove deployed',
    renameAction: 'Rename',
    renamingCiErrorTitle: 'Error renaming CI',
    repoEditPermissionTitle: 'repo edit',
    reportEmptyMessage: 'No report data available for the selected filter',
    reportErrorMessage: 'Error while fetching report',
    reportPaginationTotals: 'Total: <%= total %>',
    reportsTab: 'Reports',
    reportTabDeployments: 'Deployments',
    reportViewPermissionTitle: 'report view',
    resetButton: 'Reset',
    roleDescription: 'Provide a unique name for the role.',
    roleExitsLabel: 'Role name <%= name %> already exists',
    rolesColumnTitle: 'Roles',
    rolesTabTitle: 'Roles',
    roleTitle: 'Role',
    rollbackButton: 'Rollback',
    rollbackFlowTitle: 'Roll back <%= application %>/<%= version %> from <%= environment %>',
    ruleLabel: 'Rule',
    satellitesLabel: 'Satellites',
    saveButton: 'Save',
    scheduleButton: 'Schedule',
    scheduleConfirmLabel: 'When would you like to schedule this task?',
    scheduleDateLabel: 'Select the date',
    scheduleFailedMessage: 'Your <%= type %> for <%= date %> at <%= time %> failed.',
    scheduleFailedTitle: 'Schedule failed',
    scheduleLabel: 'Schedule',
    scheduleSucceededMessage: 'Your <%= type %> is scheduled for <%= date %> at <%= time %>.',
    scheduleSucceededTitle: 'Schedule succeeded',
    scheduleTimeLabel: 'Select the time',
    scheduleTitle: 'Schedule',
    searchCiInputPlaceholder: 'Search',
    secondsSuffix: 'sec',
    securityEditPermissionTitle: 'security edit',
    selectEnvironmentTitle: 'Select Environment',
    selectVersionTitle: 'Select Package',
    serverVersion: 'Server version: <%= serverVersion %>',
    sessionExpiredMessage: 'Session has been expired',
    showButton: 'Show',
    showFiltersButton: 'Show filters',
    skipButton: 'Skip',
    sourcePathLabel: 'Source path',
    stageConfigure: 'Configure',
    stageExecution: 'Execution',
    stageRollback: 'Rollback',
    stageUndeploy: 'Undeploy',
    startDateLabel: 'Start date',
    startLabel: 'Start',
    stateLabel: 'State',
    stayOnPageButton: 'Stay on the page',
    stepLogMessage: 'There is no log output available for a <%= state %> step.',
    stepNumberLabel: 'Step number',
    stepScriptTitle: 'Step preview',
    stopButton: 'Stop',
    submitSupportRequest: 'Submit a support request',
    successfulImport: 'Imported successfully',
    successTitle: 'Success',
    suggestFeature: 'Suggest a feature',
    supportPolicyLabel: 'Support policy',
    targetedLabel: 'targeted',
    targetLabel: 'Target',
    taskAssignPermissionTitle: 'task assign',
    taskAssignTitle: 'Assign task',
    taskAssignToLabel: 'Assign to',
    taskAssignToMe: 'Assign to me',
    taskAssignToUser: 'Assign to user...',
    taskAssignToUserDescription: 'Select a user you would like to assign this task to.',
    taskIdTitle: 'Task ID',
    taskMonitor: 'Task Monitor',
    taskMonitorErrorMessage: 'Error while fetching tasks',
    taskMoveStepPermissionTitle: 'task move step',
    taskNameLabel: 'Task Name',
    taskOpenPermissionNotGivenLabel: 'You do not have permission to view this task',
    taskPreviewStepPermissionTitle: 'task preview step',
    tasksEmptyMessage: 'No tasks available for the selected filter',
    taskSkipStepPermissionTitle: 'task skip step',
    taskSuccessfullyAssignedToUser: 'The task was successfully assigned to <%= newUser %>',
    taskTakeoverPermissionTitle: 'task takeover',
    taskWillBeAbortedNotification: 'Closing this tab will abort the running task. Are you sure you want to abort?',
    totalLabel: 'Total',
    typeLabel: 'Type',
    undeployAction: 'Undeploy',
    undeployButton: 'Undeploy',
    undeployFlowTitle: 'Undeploy <%= application %> from <%= environment %>',
    undeployment: 'undeployment',
    uniqueNameLabel: 'Please provide a unique name.',
    unknownErrorMessage: 'The application has encountered an unknown error.',
    unknownErrorTitle: 'Error',
    unsavedChangedMessage: 'There are unsaved changes. Are you sure you want to discard these changes?',
    unsavedChangesNotification: 'If you leave now, all unsaved changes will be lost.',
    unskipButton: 'Unskip',
    untargetedLabel: 'untargeted',
    updateAction: 'Update deployment',
    updateFlowTitle: 'Update deployment',
    userLabel: 'User',
    usermanagementTab: 'User Management',
    userPlaceholder: 'User',
    validationErrorTitle: 'Validation Error',
    versionColumnTitle: 'Version',
    warningsLabel: 'Warnings',
    weeksSuffix: 'wk',
    welcomePanelText: 'Quick tour of the new XL Deploy',
    xebialabsWebsite: 'XebiaLabs website',
    yesButton: 'Yes',
    youCanReopenFromTaskMonitor: 'You can open active tasks from the Task Monitor',
    zeroTimeLabel: '0 sec'
};
